@@ -66,7 +66,10 @@ impl State {
                     self.path = p;
                     refresh_directory(self);
                 },
-                FsEntry::File(p, _) => open_file(p.strip_prefix(ROOT).unwrap()),
+                FsEntry::File(p, _) => open_file(FileToOpen {
+                    path: p.strip_prefix(ROOT).unwrap().into(),
+                    ..Default::default()
+                }),
             }
         }
     }
