@@ -196,11 +196,13 @@ impl Pane for TerminalPane {
                     Some(AdjustedInput::ReRunCommandInThisPane(run_command))
                 },
                 ESC => {
+                    // Drop to shell in the same working directory as the command was run
+                    let working_dir = run_command.cwd.clone();
                     self.is_held = None;
                     self.grid.reset_terminal_state();
                     self.set_should_render(true);
                     self.remove_banner();
-                    Some(AdjustedInput::DropToShellInThisPane)
+                    Some(AdjustedInput::DropToShellInThisPane { working_dir })
                 },
                 CTRL_C => Some(AdjustedInput::CloseThisPane),
                 _ => None,
@@ -789,6 +791,7 @@ impl TerminalPane {
         invoked_with: Option<Run>,
         debug: bool,
         arrow_fonts: bool,
+        styled_underlines: bool,
     ) -> TerminalPane {
         let initial_pane_title =
             initial_pane_title.unwrap_or_else(|| format!("Pane #{}", pane_index));
@@ -803,6 +806,7 @@ impl TerminalPane {
             style.clone(),
             debug,
             arrow_fonts,
+            styled_underlines,
         );
         TerminalPane {
             frame: HashMap::new(),
