@@ -1,12 +1,16 @@
 use serde::{de::DeserializeOwned, Serialize};
-use std::collections::HashSet;
-use std::{io, path::Path};
+use std::collections::{BTreeMap, HashSet};
+use std::{
+    io,
+    path::{Path, PathBuf},
+};
 use zellij_utils::data::*;
 use zellij_utils::errors::prelude::*;
 pub use zellij_utils::plugin_api;
 use zellij_utils::plugin_api::plugin_command::ProtobufPluginCommand;
 use zellij_utils::plugin_api::plugin_ids::{ProtobufPluginIds, ProtobufZellijVersion};
 
+pub use super::ui_components::*;
 pub use zellij_utils::prost::{self, *};
 
 // Subscription Handling
@@ -87,6 +91,14 @@ pub fn open_file_floating(file_to_open: FileToOpen) {
     unsafe { host_run_plugin_command() };
 }
 
+/// Open a file in the user's default `$EDITOR`, replacing the focused pane
+pub fn open_file_in_place(file_to_open: FileToOpen) {
+    let plugin_command = PluginCommand::OpenFileInPlace(file_to_open);
+    let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
+    object_to_stdout(&protobuf_plugin_command.encode_to_vec());
+    unsafe { host_run_plugin_command() };
+}
+
 /// Open a new terminal pane to the specified location on the host filesystem
 pub fn open_terminal<P: AsRef<Path>>(path: P) {
     let file_to_open = FileToOpen::new(path.as_ref().to_path_buf());
@@ -105,8 +117,17 @@ pub fn open_terminal_floating<P: AsRef<Path>>(path: P) {
     unsafe { host_run_plugin_command() };
 }
 
+/// Open a new terminal pane to the specified location on the host filesystem, temporarily
+/// replacing the focused pane
+pub fn open_terminal_in_place<P: AsRef<Path>>(path: P) {
+    let file_to_open = FileToOpen::new(path.as_ref().to_path_buf());
+    let plugin_command = PluginCommand::OpenTerminalInPlace(file_to_open);
+    let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
+    object_to_stdout(&protobuf_plugin_command.encode_to_vec());
+    unsafe { host_run_plugin_command() };
+}
+
 /// Open a new command pane with the specified command and args (this sort of pane allows the user to control the command, re-run it and see its exit status through the Zellij UI).
-// pub fn open_command_pane<P: AsRef<Path>, A: AsRef<str>>(path: P, args: Vec<A>) {
 pub fn open_command_pane(command_to_run: CommandToRun) {
     let plugin_command = PluginCommand::OpenCommandPane(command_to_run);
     let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
@@ -115,7 +136,6 @@ pub fn open_command_pane(command_to_run: CommandToRun) {
 }
 
 /// Open a new floating command pane with the specified command and args (this sort of pane allows the user to control the command, re-run it and see its exit status through the Zellij UI).
-// pub fn open_command_pane_floating<P: AsRef<Path>, A: AsRef<str>>(path: P, args: Vec<A>) {
 pub fn open_command_pane_floating(command_to_run: CommandToRun) {
     let plugin_command = PluginCommand::OpenCommandPaneFloating(command_to_run);
     let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
@@ -123,6 +143,14 @@ pub fn open_command_pane_floating(command_to_run: CommandToRun) {
     unsafe { host_run_plugin_command() };
 }
 
+/// Open a new floating command pane with the specified command and args (this sort of pane allows the user to control the command, re-run it and see its exit status through the Zellij UI).
+pub fn open_command_pane_in_place(command_to_run: CommandToRun) {
+    let plugin_command = PluginCommand::OpenCommandPaneInPlace(command_to_run);
+    let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
+    object_to_stdout(&protobuf_plugin_command.encode_to_vec());
+    unsafe { host_run_plugin_command() };
+}
+
 /// Change the focused tab to the specified index (corresponding with the default tab names, to starting at `1`, `0` will be considered as `1`).
 pub fn switch_tab_to(tab_idx: u32) {
     let plugin_command = PluginCommand::SwitchTabTo(tab_idx);
@@ -148,6 +176,57 @@ pub fn exec_cmd(cmd: &[&str]) {
     unsafe { host_run_plugin_command() };
 }
 
+/// Run this command in the background on the host machine, optionally being notified of its output
+/// if subscribed to the `RunCommandResult` Event
+pub fn run_command(cmd: &[&str], context: BTreeMap<String, String>) {
+    let plugin_command = PluginCommand::RunCommand(
+        cmd.iter().cloned().map(|s| s.to_owned()).collect(),
+        BTreeMap::new(),
+        PathBuf::from("."),
+        context,
+    );
+    let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
+    object_to_stdout(&protobuf_plugin_command.encode_to_vec());
+    unsafe { host_run_plugin_command() };
+}
+
+/// Run this command in the background on the host machine, providing environment variables and a
+/// cwd. Optionally being notified of its output if subscribed to the `RunCommandResult` Event
+pub fn run_command_with_env_variables_and_cwd(
+    cmd: &[&str],
+    env_variables: BTreeMap<String, String>,
+    cwd: PathBuf,
+    context: BTreeMap<String, String>,
+) {
+    let plugin_command = PluginCommand::RunCommand(
+        cmd.iter().cloned().map(|s| s.to_owned()).collect(),
+        env_variables,
+        cwd,
+        context,
+    );
+    let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
+    object_to_stdout(&protobuf_plugin_command.encode_to_vec());
+    unsafe { host_run_plugin_command() };
+}
+
+/// Make a web request, optionally being notified of its output
+/// if subscribed to the `WebRequestResult` Event, the context will be returned verbatim in this
+/// event and can be used for eg. marking the request_id
+pub fn web_request<S: AsRef<str>>(
+    url: S,
+    verb: HttpVerb,
+    headers: BTreeMap<String, String>,
+    body: Vec<u8>,
+    context: BTreeMap<String, String>,
+) where
+    S: ToString,
+{
+    let plugin_command = PluginCommand::WebRequest(url.to_string(), verb, headers, body, context);
+    let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
+    object_to_stdout(&protobuf_plugin_command.encode_to_vec());
+    unsafe { host_run_plugin_command() };
+}
+
 /// Hide the plugin pane (suppress it) from the UI
 pub fn hide_self() {
     let plugin_command = PluginCommand::HideSelf;
@@ -591,11 +670,35 @@ pub fn switch_session_with_focus(
     unsafe { host_run_plugin_command() };
 }
 
+/// Permanently delete a resurrectable session with the given name
+pub fn delete_dead_session(name: &str) {
+    let plugin_command = PluginCommand::DeleteDeadSession(name.to_owned());
+    let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
+    object_to_stdout(&protobuf_plugin_command.encode_to_vec());
+    unsafe { host_run_plugin_command() };
+}
+
+/// Permanently delete aall resurrectable sessions on this machine
+pub fn delete_all_dead_sessions() {
+    let plugin_command = PluginCommand::DeleteAllDeadSessions;
+    let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
+    object_to_stdout(&protobuf_plugin_command.encode_to_vec());
+    unsafe { host_run_plugin_command() };
+}
+
+/// Rename the current session
+pub fn rename_session(name: &str) {
+    let plugin_command = PluginCommand::RenameSession(name.to_owned());
+    let protobuf_plugin_command: ProtobufPluginCommand = plugin_command.try_into().unwrap();
+    object_to_stdout(&protobuf_plugin_command.encode_to_vec());
+    unsafe { host_run_plugin_command() };
+}
+
 // Utility Functions
 
 #[allow(unused)]
 /// Returns the `TabInfo` corresponding to the currently active tab
-fn get_focused_tab(tab_infos: &Vec<TabInfo>) -> Option<TabInfo> {
+pub fn get_focused_tab(tab_infos: &Vec<TabInfo>) -> Option<TabInfo> {
     for tab_info in tab_infos {
         if tab_info.active {
             return Some(tab_info.clone());
@@ -606,7 +709,7 @@ fn get_focused_tab(tab_infos: &Vec<TabInfo>) -> Option<TabInfo> {
 
 #[allow(unused)]
 /// Returns the `PaneInfo` corresponding to the currently active pane (ignoring plugins)
-fn get_focused_pane(tab_position: usize, pane_manifest: &PaneManifest) -> Option<PaneInfo> {
+pub fn get_focused_pane(tab_position: usize, pane_manifest: &PaneManifest) -> Option<PaneInfo> {
     let panes = pane_manifest.panes.get(&tab_position);
     if let Some(panes) = panes {
         for pane in panes {
